#+TITLE: Sacha Chua's Emacs configuration
#+ELEVENTY_COLLECTIONS: _posts
#+ELEVENTY_BASE_DIR: ~/proj/static-blog/
#+ELEVENTY_CATEGORIES+: emacs
#+ELEVENTY_LAYOUT: layouts/post
#+ELEVENTY_BASE_URL: https://sachachua.com
* Org Mode: Cutting the current list item (including nested lists) with a speed command
:PROPERTIES:
:CUSTOM_ID: org-mode-keyboard-shortcuts-speed-commands-org-mode-cutting-the-current-list-item-including-nested-lists-with-a-speed-command
:EXPORT_DATE: 2025-03-29T13:14:24-0400
:EXPORT_ELEVENTY_PERMALINK: /blog/2025/03/org-mode-cutting-the-current-list-item-including-nested-lists-with-a-speed-command/
:EXPORT_ELEVENTY_FILE_NAME: blog/2025/03/org-mode-cutting-the-current-list-item-including-nested-lists-with-a-speed-command/
:END:

Defining shortcuts in ~org-speed-commands~ is
handy because you can use these single-key
shortcuts at the beginning of a subtree. With a
little modification, they'll also work at the
beginning of list items.

#+begin_src emacs-lisp
(defun my-org-use-speed-commands-for-headings-and-lists ()
  "Activate speed commands on list items too."
  (or (and (looking-at org-outline-regexp) (looking-back "^\**" nil))
      (save-excursion (and (looking-at (org-item-re)) (looking-back "^[ \t]*" nil)))))
(setq org-use-speed-commands 'my-org-use-speed-commands-for-headings-and-lists)
#+end_src

I want ~k~ to be an ~org-speed-commands~ that cuts
the current subtree or list item. This is handy
when I'm cleaning up the Mastodon toots in my
weekly review or getting rid of outline items that
I no longer need. By default, ~k~ is mapped to
~org-cut-subtree~, but it's easy to override.

#+begin_src emacs-lisp
(defun my-org-cut-subtree-or-list-item (&optional n)
	"Cut current subtree or list item."
	(cond
	 ((and (looking-at org-outline-regexp) (looking-back "^\**" nil))
		(org-cut-subtree n))
	 ((looking-at (org-item-re))
		(kill-region (org-beginning-of-item) (org-end-of-item)))))
(with-eval-after-load 'org
	(setf (alist-get "k" org-speed-commands nil nil #'string=)
				#'my-org-cut-subtree-or-list-item))
#+end_src

So now, if I put my cursor before "1." below and press ~k~:

#+begin_src org
- this
  1. is a
    - nested
  2. list
- with levels
#+end_src

it will turn into:

- this
  2. list
- with levels

You can find out a little more about [[https://orgmode.org/manual/Speed-Keys.html][Org Mode speed commands]] in the Org manual: ~(info "(org) Speed Keys")~.

